@@ -418,14 +418,10 @@ mxDataWLS <- function(data, type="WLS", useMinusTwo=TRUE, returnInverted=TRUE, d
 	nvar <- sum(ords)
 	ntvar <- ncol(data)
 	n <- dim(data)[1]
-	
-	
-	msg <- paste("Calculating asymptotic summary statistics for",
-		ntvar - nvar, "continuous and", nvar, "ordinal variables ...")
-	msgLen <- nchar(msg)
-	#message(msg)
-	imxReportProgress(msg, 0)
-	
+
+	message(paste("Calculating asymptotic summary statistics for",
+		      ntvar - nvar, "continuous and", nvar, "ordinal variables ..."))
+
 	# if no ordinal variables, use continuous-only helper
 	if(nvar ==0){ #N.B. This fails for any missing data
 		wls <- wlsContinuousOnlyHelper(data, type)
@@ -586,16 +582,9 @@ mxDataWLS <- function(data, type="WLS", useMinusTwo=TRUE, returnInverted=TRUE, d
 	
 	#TODO Figure out why certain elements of fullJac end up missing when the data are missing.
 	quad <- (n-1)*var(fullJac, use="pairwise.complete.obs") #bc colMeans all zero == t(fullJac) %*% fullJac
-	quad[is.na(quad)] <- 0
 	sel  <- diag(quad)!=0
 	iqj  <- matrix(0, dim(quad)[1], dim(quad)[2])
-	attIqj <- try(solve(quad[sel, sel]))
-	if(class(attIqj) %in% "try-error"){
-		iqj[sel,sel] <- MASS::ginv(quad[sel, sel])
-		warning('First derivative matrix was not intertible. Used pseudo-inverse instead.')
-	} else {
-		iqj[sel,sel] <- attIqj
-	}
+	iqj[sel,sel] <- solve(quad[sel, sel])
 	
 	# make the weight matrix!!!
 	wls <- fullHess %*% iqj %*% fullHess
@@ -646,8 +635,7 @@ mxDataWLS <- function(data, type="WLS", useMinusTwo=TRUE, returnInverted=TRUE, d
 	if (type=="XLS"){
 		retVal@acov <- xls
 		}
-	if (debug){return(list(fullJac, fullHess))}
-	imxReportProgress("", msgLen)
+	if (debug){return(list(fullJac, fullHess))}	
 	return(retVal)
 	}
 
