@@ -336,12 +336,12 @@ ordinalizeDataHelper <- function(data, thresh, origData=NULL) {
 		for(avar in ordvars){
 			delthr <- thresh[,avar]
 			usethr <- 1:sum(!is.na(delthr))  # assumes NA indicates unused threshold
-			if (!is.null(origData) && !is.null(origData[[avar]])) {
+			if (!is.null(origData)) {
 				usethr <- 1:(length(levels(origData[[avar]])) - 1L)
 			}
 			delthr <- delthr[usethr]
 			levthr <- 1L:(length(usethr)+1L)
-			if (!is.null(origData)  && !is.null(origData[[avar]])) {
+			if (!is.null(origData)) {
 				levthr <- levels(origData[[avar]])
 			}
 			delvar <- cut(as.vector(data[,avar]), c(-Inf, delthr, Inf), labels=levthr)
@@ -351,42 +351,7 @@ ordinalizeDataHelper <- function(data, thresh, origData=NULL) {
 	return(data)
 }
 
-generateRelationalData <- function(model, returnModel, .backend) {
-	if (.backend) {
-		plan <- mxComputeGenerateData()
-		modelE <- mxModel(model, plan)
-		modelE <- mxRun(modelE, silent=TRUE)
-		simData <- modelE$compute$output
-
-		datalist <- modelE@runstate$datalist
-		for (dName in names(datalist)) {
-			if (is.null(simData[[dName]])) {
-				simData[[dName]] <- datalist[[dName]]$observed
-			} else {
-				orig <- datalist[[dName]]$observed
-				toCopy <- setdiff(colnames(orig), colnames(simData[[dName]]))
-				for (col in toCopy) {
-					simData[[dName]][[col]] <- orig[[col]]
-				}
-			}
-		}
-
-		names(simData) <- substr(names(simData), 1, nchar(names(simData))-5) #strip .data
-
-		if (!returnModel) {
-			return(simData)
-		} else {
-			for (modelName in names(simData)) {
-				if (modelName == model$name) {
-					model@data@observed <- simData[[modelName]]
-				} else {
-					model[[modelName]]@data@observed <- simData[[modelName]]
-				}
-			}
-			return(model)
-		}
-	}
-
+generateRelationalData <- function(model, returnModel) {
 	plan <- mxComputeSequence(list(
 	    mxComputeOnce('expectation', 'distribution', 'flat'),
 	    mxComputeReportExpectation()
@@ -451,12 +416,7 @@ generateRelationalData <- function(model, returnModel, .backend) {
 	}
 }
 
-mxGenerateData <- function(model, nrows=NULL, returnModel=FALSE, use.miss = TRUE,
-			   ..., .backend=TRUE) {
-	garbageArguments <- list(...)
-	if (length(garbageArguments) > 0) {
-		stop("mxGenerateData does not accept values for the '...' argument")
-	}
+mxGenerateData <- function(model, nrows=NULL, returnModel=FALSE, use.miss = TRUE) {
 	if (is(model, 'data.frame')) {
 		wlsData <- mxDataWLS(model)
 		fake <- mxModel("fake",
@@ -471,11 +431,10 @@ mxGenerateData <- function(model, nrows=NULL, returnModel=FALSE, use.miss = TRUE
 	fellner <- is(model$expectation, "MxExpectationRAM") && length(model$expectation$between);
 	if (!fellner) {
 		origData <- NULL
-		if (!is.null(model@data) && model@data@type == 'raw') {
+		if (!is.null(model@data)) {
 			origData <- model@data@observed
 			if (missing(nrows)) nrows <- nrow(origData)
 		}
-		if (is.null(nrows)) stop("You must specify nrows")
 		data <- genericGenerateData(model$expectation, model, nrows)
 		if (use.miss && !is.null(origData) && all(colnames(data) %in% colnames(origData))) {
 			del <- is.na(origData[,colnames(data),drop=FALSE])
@@ -496,7 +455,7 @@ mxGenerateData <- function(model, nrows=NULL, returnModel=FALSE, use.miss = TRUE
 		if (!missing(nrows)) {
 			stop("Specification of the number of rows is not supported for relational models")
 		}
-		generateRelationalData(model, returnModel, .backend)
+		generateRelationalData(model, returnModel)
 	}
 }
 
