@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2016 The OpenMx Project
+#   Copyright 2007-2017 The OpenMx Project
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -70,7 +70,7 @@ oneFactorModel <- mxModel("Common Factor Model Path Specification", type="RAM",
 oneFactorFit <- mxRun(oneFactorModel)      
 
 summary(oneFactorFit)
-oneFactorFit$output$estimate
+coef(oneFactorFit)
 
 omxCheckCloseEnough(oneFactorFit$output$estimate[["l2"]], 0.999, 0.01)
 omxCheckCloseEnough(oneFactorFit$output$estimate[["l3"]], 0.959, 0.01)
@@ -91,4 +91,4 @@ omxCheckCloseEnough(oneFactorFit$output$estimate[["meanx4"]], 3.053, 0.01)
 omxCheckCloseEnough(oneFactorFit$output$estimate[["meanx5"]], 3.016, 0.01)
 omxCheckCloseEnough(oneFactorFit$output$estimate[["meanx6"]], 3.010, 0.01)
 # Compare OpenMx results to Mx results 
-# -----------------------------------------------------------------------------
\ No newline at end of file
+# -----------------------------------------------------------------------------
